# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/abci/v1beta2/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta2 import params_pb2 as cometbft_dot_types_dot_v1beta2_dot_params__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/abci/v1beta2/types.proto\x12\x15\x63ometbft.abci.v1beta2\x1a\x14gogoproto/gogo.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a#cometbft/types/v1beta2/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\t\n\x07Request\x12\x38\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\".cometbft.abci.v1beta1.RequestEchoH\x00R\x04\x65\x63ho\x12;\n\x05\x66lush\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestFlushH\x00R\x05\x66lush\x12\x38\n\x04info\x18\x03 \x01(\x0b\x32\".cometbft.abci.v1beta2.RequestInfoH\x00R\x04info\x12H\n\ninit_chain\x18\x05 \x01(\x0b\x32\'.cometbft.abci.v1beta2.RequestInitChainH\x00R\tinitChain\x12;\n\x05query\x18\x06 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestQueryH\x00R\x05query\x12K\n\x0b\x62\x65gin_block\x18\x07 \x01(\x0b\x32(.cometbft.abci.v1beta2.RequestBeginBlockH\x00R\nbeginBlock\x12\x42\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32%.cometbft.abci.v1beta1.RequestCheckTxH\x00R\x07\x63heckTx\x12H\n\ndeliver_tx\x18\t \x01(\x0b\x32\'.cometbft.abci.v1beta1.RequestDeliverTxH\x00R\tdeliverTx\x12\x45\n\tend_block\x18\n \x01(\x0b\x32&.cometbft.abci.v1beta1.RequestEndBlockH\x00R\x08\x65ndBlock\x12>\n\x06\x63ommit\x18\x0b \x01(\x0b\x32$.cometbft.abci.v1beta1.RequestCommitH\x00R\x06\x63ommit\x12T\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestListSnapshotsH\x00R\rlistSnapshots\x12T\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestOfferSnapshotH\x00R\rofferSnapshot\x12\x61\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32/.cometbft.abci.v1beta1.RequestLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x64\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12Z\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32-.cometbft.abci.v1beta2.RequestPrepareProposalH\x00R\x0fprepareProposal\x12Z\n\x10process_proposal\x18\x11 \x01(\x0b\x32-.cometbft.abci.v1beta2.RequestProcessProposalH\x00R\x0fprocessProposalB\x07\n\x05valueJ\x04\x08\x04\x10\x05\"\x90\x01\n\x0bRequestInfo\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12#\n\rblock_version\x18\x02 \x01(\x04R\x0c\x62lockVersion\x12\x1f\n\x0bp2p_version\x18\x03 \x01(\x04R\np2pVersion\x12!\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\tR\x0b\x61\x62\x63iVersion\"\xd8\x02\n\x10RequestInitChain\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12R\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x04 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12&\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0cR\rappStateBytes\x12%\n\x0einitial_height\x18\x06 \x01(\x03R\rinitialHeight\"\x95\x02\n\x11RequestBeginBlock\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12<\n\x06header\x18\x02 \x01(\x0b\x32\x1e.cometbft.types.v1beta1.HeaderB\x04\xc8\xde\x1f\x00R\x06header\x12Q\n\x10last_commit_info\x18\x03 \x01(\x0b\x32!.cometbft.abci.v1beta2.CommitInfoB\x04\xc8\xde\x1f\x00R\x0elastCommitInfo\x12[\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x13\x62yzantineValidators\"\xa4\x03\n\x16RequestPrepareProposal\x12 \n\x0cmax_tx_bytes\x18\x01 \x01(\x03R\nmaxTxBytes\x12\x10\n\x03txs\x18\x02 \x03(\x0cR\x03txs\x12[\n\x11local_last_commit\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta2.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00R\x0flocalLastCommit\x12J\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x94\x03\n\x16RequestProcessProposal\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12Y\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta2.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12J\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\xba\n\n\x08Response\x12H\n\texception\x18\x01 \x01(\x0b\x32(.cometbft.abci.v1beta1.ResponseExceptionH\x00R\texception\x12\x39\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseEchoH\x00R\x04\x65\x63ho\x12<\n\x05\x66lush\x18\x03 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseFlushH\x00R\x05\x66lush\x12\x39\n\x04info\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseInfoH\x00R\x04info\x12I\n\ninit_chain\x18\x06 \x01(\x0b\x32(.cometbft.abci.v1beta2.ResponseInitChainH\x00R\tinitChain\x12<\n\x05query\x18\x07 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseQueryH\x00R\x05query\x12L\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32).cometbft.abci.v1beta2.ResponseBeginBlockH\x00R\nbeginBlock\x12\x43\n\x08\x63heck_tx\x18\t \x01(\x0b\x32&.cometbft.abci.v1beta2.ResponseCheckTxH\x00R\x07\x63heckTx\x12I\n\ndeliver_tx\x18\n \x01(\x0b\x32(.cometbft.abci.v1beta2.ResponseDeliverTxH\x00R\tdeliverTx\x12\x46\n\tend_block\x18\x0b \x01(\x0b\x32\'.cometbft.abci.v1beta2.ResponseEndBlockH\x00R\x08\x65ndBlock\x12?\n\x06\x63ommit\x18\x0c \x01(\x0b\x32%.cometbft.abci.v1beta1.ResponseCommitH\x00R\x06\x63ommit\x12U\n\x0elist_snapshots\x18\r \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseListSnapshotsH\x00R\rlistSnapshots\x12U\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseOfferSnapshotH\x00R\rofferSnapshot\x12\x62\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x65\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12[\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponsePrepareProposalH\x00R\x0fprepareProposal\x12[\n\x10process_proposal\x18\x12 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponseProcessProposalH\x00R\x0fprocessProposalB\x07\n\x05valueJ\x04\x08\x05\x10\x06\"\xd0\x01\n\x11ResponseInitChain\x12R\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x02 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12\x19\n\x08\x61pp_hash\x18\x03 \x01(\x0cR\x07\x61ppHash\"d\n\x12ResponseBeginBlock\x12N\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\xe2\x02\n\x0fResponseCheckTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\x12\x16\n\x06sender\x18\t \x01(\tR\x06sender\x12\x1a\n\x08priority\x18\n \x01(\x03R\x08priority\x12#\n\rmempool_error\x18\x0b \x01(\tR\x0cmempoolError\"\x8b\x02\n\x11ResponseDeliverTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\"\x9e\x02\n\x10ResponseEndBlock\x12Y\n\x11validator_updates\x18\x01 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12_\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x15\x63onsensusParamUpdates\x12N\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"+\n\x17ResponsePrepareProposal\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\"\xa7\x01\n\x17ResponseProcessProposal\x12U\n\x06status\x18\x01 \x01(\x0e\x32=.cometbft.abci.v1beta2.ResponseProcessProposal.ProposalStatusR\x06status\"5\n\x0eProposalStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\"_\n\nCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12;\n\x05votes\x18\x02 \x03(\x0b\x32\x1f.cometbft.abci.v1beta1.VoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"o\n\x12\x45xtendedCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12\x43\n\x05votes\x18\x02 \x03(\x0b\x32\'.cometbft.abci.v1beta2.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"\x80\x01\n\x05\x45vent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x63\n\nattributes\x18\x02 \x03(\x0b\x32%.cometbft.abci.v1beta2.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitemptyR\nattributes\"N\n\x0e\x45ventAttribute\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12\x14\n\x05index\x18\x03 \x01(\x08R\x05index\"\xab\x01\n\x10\x45xtendedVoteInfo\x12\x44\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12*\n\x11signed_last_block\x18\x02 \x01(\x08R\x0fsignedLastBlock\x12%\n\x0evote_extension\x18\x03 \x01(\x0cR\rvoteExtension\"\x8f\x02\n\x0bMisbehavior\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.cometbft.abci.v1beta2.MisbehaviorTypeR\x04type\x12\x44\n\tvalidator\x18\x02 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12,\n\x12total_voting_power\x18\x05 \x01(\x03R\x10totalVotingPower*K\n\x0fMisbehaviorType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\xbb\x0c\n\x0f\x41\x42\x43IApplication\x12O\n\x04\x45\x63ho\x12\".cometbft.abci.v1beta1.RequestEcho\x1a#.cometbft.abci.v1beta1.ResponseEcho\x12R\n\x05\x46lush\x12#.cometbft.abci.v1beta1.RequestFlush\x1a$.cometbft.abci.v1beta1.ResponseFlush\x12O\n\x04Info\x12\".cometbft.abci.v1beta2.RequestInfo\x1a#.cometbft.abci.v1beta1.ResponseInfo\x12^\n\tDeliverTx\x12\'.cometbft.abci.v1beta1.RequestDeliverTx\x1a(.cometbft.abci.v1beta2.ResponseDeliverTx\x12X\n\x07\x43heckTx\x12%.cometbft.abci.v1beta1.RequestCheckTx\x1a&.cometbft.abci.v1beta2.ResponseCheckTx\x12R\n\x05Query\x12#.cometbft.abci.v1beta1.RequestQuery\x1a$.cometbft.abci.v1beta1.ResponseQuery\x12U\n\x06\x43ommit\x12$.cometbft.abci.v1beta1.RequestCommit\x1a%.cometbft.abci.v1beta1.ResponseCommit\x12^\n\tInitChain\x12\'.cometbft.abci.v1beta2.RequestInitChain\x1a(.cometbft.abci.v1beta2.ResponseInitChain\x12\x61\n\nBeginBlock\x12(.cometbft.abci.v1beta2.RequestBeginBlock\x1a).cometbft.abci.v1beta2.ResponseBeginBlock\x12[\n\x08\x45ndBlock\x12&.cometbft.abci.v1beta1.RequestEndBlock\x1a\'.cometbft.abci.v1beta2.ResponseEndBlock\x12j\n\rListSnapshots\x12+.cometbft.abci.v1beta1.RequestListSnapshots\x1a,.cometbft.abci.v1beta1.ResponseListSnapshots\x12j\n\rOfferSnapshot\x12+.cometbft.abci.v1beta1.RequestOfferSnapshot\x1a,.cometbft.abci.v1beta1.ResponseOfferSnapshot\x12v\n\x11LoadSnapshotChunk\x12/.cometbft.abci.v1beta1.RequestLoadSnapshotChunk\x1a\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunk\x12y\n\x12\x41pplySnapshotChunk\x12\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunk\x1a\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunk\x12p\n\x0fPrepareProposal\x12-.cometbft.abci.v1beta2.RequestPrepareProposal\x1a..cometbft.abci.v1beta2.ResponsePrepareProposal\x12p\n\x0fProcessProposal\x12-.cometbft.abci.v1beta2.RequestProcessProposal\x1a..cometbft.abci.v1beta2.ResponseProcessProposalB\xd5\x01\n\x19\x63om.cometbft.abci.v1beta2B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta2\xa2\x02\x03\x43\x41X\xaa\x02\x15\x43ometbft.Abci.V1beta2\xca\x02\x15\x43ometbft\\Abci\\V1beta2\xe2\x02!Cometbft\\Abci\\V1beta2\\GPBMetadata\xea\x02\x17\x43ometbft::Abci::V1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.abci.v1beta2B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta2\242\002\003CAX\252\002\025Cometbft.Abci.V1beta2\312\002\025Cometbft\\Abci\\V1beta2\342\002!Cometbft\\Abci\\V1beta2\\GPBMetadata\352\002\027Cometbft::Abci::V1beta2'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MISBEHAVIORTYPE']._serialized_start=6731
  _globals['_MISBEHAVIORTYPE']._serialized_end=6806
  _globals['_REQUEST']._serialized_start=224
  _globals['_REQUEST']._serialized_end=1471
  _globals['_REQUESTINFO']._serialized_start=1474
  _globals['_REQUESTINFO']._serialized_end=1618
  _globals['_REQUESTINITCHAIN']._serialized_start=1621
  _globals['_REQUESTINITCHAIN']._serialized_end=1965
  _globals['_REQUESTBEGINBLOCK']._serialized_start=1968
  _globals['_REQUESTBEGINBLOCK']._serialized_end=2245
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_start=2248
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_end=2668
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_start=2671
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_end=3075
  _globals['_RESPONSE']._serialized_start=3078
  _globals['_RESPONSE']._serialized_end=4416
  _globals['_RESPONSEINITCHAIN']._serialized_start=4419
  _globals['_RESPONSEINITCHAIN']._serialized_end=4627
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=4629
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=4729
  _globals['_RESPONSECHECKTX']._serialized_start=4732
  _globals['_RESPONSECHECKTX']._serialized_end=5086
  _globals['_RESPONSEDELIVERTX']._serialized_start=5089
  _globals['_RESPONSEDELIVERTX']._serialized_end=5356
  _globals['_RESPONSEENDBLOCK']._serialized_start=5359
  _globals['_RESPONSEENDBLOCK']._serialized_end=5645
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_start=5647
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_end=5690
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_start=5693
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_end=5860
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_start=5807
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_end=5860
  _globals['_COMMITINFO']._serialized_start=5862
  _globals['_COMMITINFO']._serialized_end=5957
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=5959
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6070
  _globals['_EVENT']._serialized_start=6073
  _globals['_EVENT']._serialized_end=6201
  _globals['_EVENTATTRIBUTE']._serialized_start=6203
  _globals['_EVENTATTRIBUTE']._serialized_end=6281
  _globals['_EXTENDEDVOTEINFO']._serialized_start=6284
  _globals['_EXTENDEDVOTEINFO']._serialized_end=6455
  _globals['_MISBEHAVIOR']._serialized_start=6458
  _globals['_MISBEHAVIOR']._serialized_end=6729
  _globals['_ABCIAPPLICATION']._serialized_start=6809
  _globals['_ABCIAPPLICATION']._serialized_end=8404
# @@protoc_insertion_point(module_scope)
