# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/state/v1beta3/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.state.v1beta1 import types_pb2 as cometbft_dot_state_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta2 import types_pb2 as cometbft_dot_abci_dot_v1beta2_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta3 import types_pb2 as cometbft_dot_abci_dot_v1beta3_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cometbft/state/v1beta3/types.proto\x12\x16\x63ometbft.state.v1beta3\x1a\"cometbft/state/v1beta1/types.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a!cometbft/abci/v1beta2/types.proto\x1a!cometbft/abci/v1beta3/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x01\n\x13LegacyABCIResponses\x12\x44\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultR\ndeliverTxs\x12\x45\n\tend_block\x18\x02 \x01(\x0b\x32(.cometbft.state.v1beta3.ResponseEndBlockR\x08\x65ndBlock\x12K\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32*.cometbft.state.v1beta3.ResponseBeginBlockR\nbeginBlock\"d\n\x12ResponseBeginBlock\x12N\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\x99\x02\n\x10ResponseEndBlock\x12Y\n\x11validator_updates\x18\x01 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12Z\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x15\x63onsensusParamUpdates\x12N\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\x9a\x01\n\x13\x43onsensusParamsInfo\x12S\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12.\n\x13last_height_changed\x18\x02 \x01(\x03R\x11lastHeightChanged\"\xf2\x01\n\x11\x41\x42\x43IResponsesInfo\x12_\n\x15legacy_abci_responses\x18\x01 \x01(\x0b\x32+.cometbft.state.v1beta3.LegacyABCIResponsesR\x13legacyAbciResponses\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x64\n\x17response_finalize_block\x18\x03 \x01(\x0b\x32,.cometbft.abci.v1beta3.ResponseFinalizeBlockR\x15responseFinalizeBlock\"\x80\x07\n\x05State\x12?\n\x07version\x18\x01 \x01(\x0b\x32\x1f.cometbft.state.v1beta1.VersionB\x04\xc8\xde\x1f\x00R\x07version\x12&\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDR\x07\x63hainId\x12%\n\x0einitial_height\x18\x0e \x01(\x03R\rinitialHeight\x12*\n\x11last_block_height\x18\x03 \x01(\x03R\x0flastBlockHeight\x12X\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockIDR\x0blastBlockId\x12L\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\rlastBlockTime\x12M\n\x0fnext_validators\x18\x06 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0enextValidators\x12\x44\n\nvalidators\x18\x07 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\nvalidators\x12M\n\x0flast_validators\x18\x08 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0elastValidators\x12\x43\n\x1elast_height_validators_changed\x18\t \x01(\x03R\x1blastHeightValidatorsChanged\x12S\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12N\n$last_height_consensus_params_changed\x18\x0b \x01(\x03R lastHeightConsensusParamsChanged\x12*\n\x11last_results_hash\x18\x0c \x01(\x0cR\x0flastResultsHash\x12\x19\n\x08\x61pp_hash\x18\r \x01(\x0cR\x07\x61ppHashB\xdb\x01\n\x1a\x63om.cometbft.state.v1beta3B\nTypesProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta3\xa2\x02\x03\x43SX\xaa\x02\x16\x43ometbft.State.V1beta3\xca\x02\x16\x43ometbft\\State\\V1beta3\xe2\x02\"Cometbft\\State\\V1beta3\\GPBMetadata\xea\x02\x18\x43ometbft::State::V1beta3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1beta3.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.state.v1beta3B\nTypesProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta3\242\002\003CSX\252\002\026Cometbft.State.V1beta3\312\002\026Cometbft\\State\\V1beta3\342\002\"Cometbft\\State\\V1beta3\\GPBMetadata\352\002\030Cometbft::State::V1beta3'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_LEGACYABCIRESPONSES']._serialized_start=367
  _globals['_LEGACYABCIRESPONSES']._serialized_end=606
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=608
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=708
  _globals['_RESPONSEENDBLOCK']._serialized_start=711
  _globals['_RESPONSEENDBLOCK']._serialized_end=992
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=995
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=1149
  _globals['_ABCIRESPONSESINFO']._serialized_start=1152
  _globals['_ABCIRESPONSESINFO']._serialized_end=1394
  _globals['_STATE']._serialized_start=1397
  _globals['_STATE']._serialized_end=2293
# @@protoc_insertion_point(module_scope)
